@@ -46,7 +46,7 @@ use Data::Dumper;
 
 #  Version information
 #
-$VERSION='1.244';
+$VERSION='1.246';
 
 
 #  Debug load
@@ -374,10 +374,12 @@ sub block {
 
 sub script {
 
-    my ($self, $method)=(shift, shift);
+    my ($self, $method, $tag, $attr_hr)=@_;
     debug('script');
     $Text_fg='script';
-    $self->$method(@_);
+    my $or=$self->$method($tag, $attr_hr, @_);
+    $or->postinsert('</script>') if $attr_hr->{'src'};
+    $or;
 
 }
 
